about summary refs log tree commit diff
path: root/users/flokli/ipu6-softisp/default.nix
diff options
context:
space:
mode:
Diffstat (limited to 'users/flokli/ipu6-softisp/default.nix')
-rw-r--r--users/flokli/ipu6-softisp/default.nix23
1 files changed, 13 insertions, 10 deletions
diff --git a/users/flokli/ipu6-softisp/default.nix b/users/flokli/ipu6-softisp/default.nix
index 1f603dbb4283..ab129d1bc85e 100644
--- a/users/flokli/ipu6-softisp/default.nix
+++ b/users/flokli/ipu6-softisp/default.nix
@@ -11,8 +11,8 @@
 let
   systemFor = sys: (depot.ops.nixos.nixosFor sys).system;
 in
-depot.nix.readTree.drvTargets rec {
-  testSystem = systemFor ({ modulesPath, pkgs, ... }: {
+(depot.nix.readTree.drvTargets rec {
+  testSystem = (systemFor ({ modulesPath, pkgs, ... }: {
     imports = [
       # Import the module, this is something a user would do in their config.
       ./config.nix
@@ -39,19 +39,22 @@ depot.nix.readTree.drvTargets rec {
 
     # Shut off the warning.
     system.stateVersion = "24.05";
-  });
+  })) // {
+    # 2024-07-28 aspen: The patches no longer cleanly apply on upstream
+    meta.broken = true;
+  };
 
   # Make sure the firmware requested by the driver is present in our firmware.
   # We do have a .xz suffix here, but that's fine, since request_firmware does
   # check ${name}.xz too in case CONFIG_FW_LOADER_COMPRESS is set.
   # The path needs to be kept in sync with the ones used in the kernel patch.
   checkFirmware = pkgs.runCommand "check-firmware" { } ''
-    stat ${testSystem}/firmware/intel/ipu/ipu6se_fw.bin.xz
-    stat ${testSystem}/firmware/intel/ipu/ipu6ep_fw.bin.xz
-    stat ${testSystem}/firmware/intel/ipu/ipu6_fw.bin.xz
-    stat ${testSystem}/firmware/intel/ipu/ipu6epmtl_fw.bin.xz
+    stat ${testSystem}/firmware/intel/ipu/ipu6se_fw.bin.zst
+    stat ${testSystem}/firmware/intel/ipu/ipu6ep_fw.bin.zst
+    stat ${testSystem}/firmware/intel/ipu/ipu6_fw.bin.zst
+    stat ${testSystem}/firmware/intel/ipu/ipu6epmtl_fw.bin.zst
 
     # all good, succeed build
     touch $out
   '';
-}
+})
@@ -39,19 +39,22 @@ depot.nix.readTree.drvTargets rec {
 
   # Make sure the firmware requested by the driver is present in our firmware.
-  # We do have a .xz suffix here, but that's fine, since request_firmware does
-  # check ${name}.xz too in case CONFIG_FW_LOADER_COMPRESS is set.
+  # We do have a .zst suffix here, but that's fine, since request_firmware does
+  # check ${name}.zst too in case CONFIG_FW_LOADER_COMPRESS is set.
   # The path needs to be kept in sync with the ones used in the kernel patch.
   checkFirmware = pkgs.runCommand "check-firmware" { } ''